| BC | R Documentation |
Class for storing BC data and associated functions for analysis of backcross family populations.
## Create BC object
BCobj <- makeBC(RAobj, pedfile, family=NULL, inferSNPs=FALSE,
filter=list(MAF=0.05, MISS=0.2, BIN=100, DEPTH=5, PVALUE=0.01, MAXDEPTH=500))
## Functions (Methods) of an BC object
BCobj$addBIsnps(LODthres = 10, nComp = 10)
BCobj$iaddSNPs(LODthres = 10, nComp = 10)
BCobj$computeMap(chrom = NULL, init_r = 0.01, ep = 0.001, method = NULL, err = T, mapped = T, nThreads = 1, rfthres = 0.1)
BCobj$createLG(parent = "both", LODthres = 10, nComp = 10, reset = FALSE)
BCobj$maskSNP(snps)
BCobj$mergeLG(LG, where = NULL, mergeTo = NULL)
BCobj$orderLG(chrom = NULL, mapfun = "haldane", weight = "LOD2", ndim = 30, spar = NULL)
BCobj$plotChr(parent = "maternal", mat = "rf", filename = NULL, chrS = 2, lmai = 0.25)
BCobj$plotLG(parent = "both", LG = NULL, mat = "rf", filename = NULL, interactive = FALSE, what = NULL)
BCobj$plotLM(LG = NULL, fun = "haldane", col = "black")
BCobj$plotSyn()
BCobj$print(what = NULL, ...)
BCobj$removeLG(LG, where = NULL)
BCobj$removeSNP(snps, where = NULL)
BCobj$rf_2pt(nClust = 2, err = FALSE)
BCobj$unmaskSNP(snps)
BCobj$writeLM(file, direct = "./", LG = NULL, what = NULL, inferGeno = TRUE)
An BC object is created from the makeBC function and contains RA data,
various statistics of the dataset that have been computed, and functions (methods)
for analyzing the data. Information in an BC object are specific to backcross family populations.
$addBIsnpsAdd Both-Informative (BI) snps to the maternal and/or paternal linkage groups.
$addSNPsAdd MI, PI and/or SI SNPs to the existing linkage groups
$createLGCreate linkage group(s).
$computeMapCompute linkage maps for a given marker order.
$maskSNPMask SNP(s) in the dataset.
$mergeLGMerge linkage groups.
$orderLGOrder the SNPs in the linkage group(s).
$plotChrPlot the heatmap of the 2-point recombination fraction estimates (or LOD scores) when SNPs are ordered according to the genome assembly.
$plotLGPlot the heatmap of the 2-point recombination fraction estimates (or LOD scores) when SNPs are ordered according to their linkage groups.
$plotLMPlot linkage maps.
$plotSynProduce a Synteny plot.
$printPrint summary information for BC object.
$removeLGRemove linkage group(s).
$removeSNPRemove SNP(s) from linkage group(s).
$rf_2ptCompute the 2-point recombination fraction (and LOD score) between all SNP pairs.
$unmaskSNPUnmask SNP(s) in the data set.
$writeLMWrite linkage mapping results to a file.
GUSbase::RA -> BC
new()BC$new(R6obj)
print()BC$print(what = NULL, ...)
removeSNP()BC$removeSNP(snps, where = NULL)
removeLG()BC$removeLG(LG, where = NULL)
mergeLG()BC$mergeLG(LG, where = NULL, mergeTo = NULL)
maskSNP()BC$maskSNP(snps)
unmaskSNP()BC$unmaskSNP(snps)
rf_2pt()BC$rf_2pt(nClust = 2, err = FALSE)
createLG()BC$createLG(parent = "both", LODthres = 10, nComp = 10, reset = FALSE)
addSNPs()BC$addSNPs(LODthres = 10, nComp = 10)
addBIsnps()BC$addBIsnps(LODthres = 10, nComp = 10)
orderLG()BC$orderLG( LG = NULL, mapfun = "haldane", weight = "LOD2", ndim = 30, spar = NULL, filename = NULL )
plotLG()BC$plotLG( parent = "both", LG = NULL, mat = "rf", filename = NULL, interactive = FALSE, what = NULL, ... )
plotChr()BC$plotChr(
chrom = NULL,
parent = "maternal",
mat = c("rf"),
filename = NULL,
chrS = 2,
lmai = 0.25
)plotLM()BC$plotLM(LG = NULL, fun = "haldane", col = "black")
plotSyn()BC$plotSyn()
computeMap()BC$computeMap( parent = "both", chrom = NULL, init_r = 0.001, ep = 0.001, method = NULL, err = TRUE, multiErr = FALSE, mapped = TRUE, nThreads = 1, inferOPGP = TRUE, rfthres = 0.1 )
cometPlot()BC$cometPlot( filename = NULL, cex = 1, maxdepth = 500, maxSNPs = 1e+05, res = 300, color = NULL, ind = FALSE, ncores = 1, ... )
rocketPlot()BC$rocketPlot( ploid = 2, filename = NULL, cex = 1, maxdepth = 500, maxSNPs = 1e+05, res = 300, scaled = TRUE, ... )
RDDPlot()BC$RDDPlot(filename = NULL, maxdepth = 500, maxSNPs = 1e+05, ...)
writeLM()BC$writeLM(file, direct = "./", LG = NULL, what = NULL, inferGeno = TRUE)
clone()The objects of this class are cloneable with this method.
BC$clone(deep = FALSE)
deepWhether to make a deep clone.
Timothy P. Bilton
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.