| IC | R Documentation |
Class for storing RA data and associated functions for analysis of intercross (F2) populations.
## Create IC object
ICobj <- makeIC(RAobj, samID=NULL,
filter=list(MAF=0.05, MISS=0.2, BIN=100, DEPTH=5, PVALUE=0.01, MAXDEPTH=500))
## Functions (Methods) of an IC object
ICobj$computeMap(chrom = NULL, init_r = 0.01, ep = 0.001, method = "EM", err = T, mapped = T, nThreads = 1)
ICobj$createLG(LODthres = 10, nComp = 10)
ICobj$maskSNP(snps)
ICobj$mergeLG(LG)
ICobj$orderLG(chrom = NULL, mapfun = "haldane", weight = "LOD2", ndim = 30, spar = NULL)
ICobj$plotChr(mat = "rf", filename = NULL, chrS = 2, lmai = 2)
ICobj$plotLG(LG = NULL, mat = "rf", filename = NULL, interactive = TRUE)
ICobj$plotLM(LG = NULL, fun = "haldane", col = "black")
ICobj$plotSyn()
ICobj$print(what = NULL, ...)
ICobj$removeLG(LG)
ICobj$removeSNP(snps)
ICobj$rf_2pt(nClust = 2, err=FALSE)
ICobj$unmaskSNP(snps)
ICobj$writeLM(file, direct = "./", LG = NULL, what = NULL, inferGeno = TRUE)
An IC object is created from the makeIC function and contains RA data,
various statistics of the dataset that have been computed, and functions (methods)
for analyzing the data. Information in an IC object are specific to intercross (F2) populations.
$createLGCreate linkage group(s).
$computeMapCompute linkage maps for a given marker order.
$maskSNPMask SNP(s) in the dataset.
$mergeLGMerge linkage groups.
$orderLGOrder the SNPs in the linkage group(s).
$plotChrPlot the heatmap of the 2-point recombination fraction estimates (or LOD scores) when SNPs are ordered according to the genome assembly.
$plotLGPlot the heatmap of the 2-point recombination fraction estimates (or LOD scores) when SNPs are ordered according to their linkage groups.
$plotLMPlot linkage maps.
$plotSynProduce a Synteny plot.
$printPrint summary information for FS object.
$removeLGRemove linkage group(s).
$removeSNPRemove SNP(s) from linkage group(s).
$rf_2ptCompute the 2-point recombination fraction (and LOD score) between all SNP pairs.
$unmaskSNPUnmask SNP(s) in the data set.
$writeLMWrite linkage mapping results to a file.
GUSbase::RA -> IC
new()IC$new(R6obj)
print()IC$print(what = NULL, ...)
removeSNP()IC$removeSNP(snps)
removeLG()IC$removeLG(LG)
mergeLG()IC$mergeLG(LG)
maskSNP()IC$maskSNP(snps)
unmaskSNP()IC$unmaskSNP(snps)
rf_2pt()IC$rf_2pt(nClust = 2, err = FALSE)
createLG()IC$createLG(LODthres = 10, nComp = 10, reset = FALSE)
orderLG()IC$orderLG( LG = NULL, mapfun = "haldane", weight = "LOD2", ndim = 30, spar = NULL, filename = NULL )
plotLG()IC$plotLG(LG = NULL, mat = "rf", filename = NULL, interactive = TRUE, ...)
plotChr()IC$plotChr(chrom = NULL, mat = c("rf"), filename = NULL, chrS = 2, lmai = 2)plotLM()IC$plotLM(LG = NULL, fun = "haldane", col = "black")
plotSyn()IC$plotSyn()
computeMap()IC$computeMap( chrom = NULL, init_r = 0.001, ep = 0.001, method = "EM", err = TRUE, multiErr = FALSE, mapped = TRUE, nThreads = 1, inferOPGP = TRUE, rfthres = 0.1, ... )
writeLM()IC$writeLM(file, direct = "./", LG = NULL, what = NULL, inferGeno = TRUE)
cometPlot()IC$cometPlot( filename = NULL, cex = 1, maxdepth = 500, maxSNPs = 1e+05, res = 300, color = NULL, ind = FALSE, ncores = 1, ... )
rocketPlot()IC$rocketPlot( ploid = 2, filename = NULL, cex = 1, maxdepth = 500, maxSNPs = 1e+05, res = 300, scaled = TRUE, ... )
RDDPlot()IC$RDDPlot(filename = NULL, maxdepth = 500, maxSNPs = 1e+05, ...)
clone()The objects of this class are cloneable with this method.
IC$clone(deep = FALSE)
deepWhether to make a deep clone.
Timothy P. Bilton
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.