| R Documentation |
Method for printing summary information of an BC, FS or IC object
BCobj$print(what = NULL, ...)
FSobj$print(what = NULL, ...)
ICobj$print(what = NULL, ...)
what |
Character vector giving the type of information to be printed. IF |
There are four types of information availabe to be printed for an object (as specified by the what argument).
BC object:
"data"Summary information of the data as process by the makeBC function.
"LG-pts"Summary information of the pesudo-testcross linkage groups produced by the $createLG function.
"LG-bi"Summary information of the combined linkage groups produced by either the $addBIsnps or $orderLG functions.
"map"Summary information of the linkage maps produced by the $computeMap function.
FS object:
"data"Summary information of the data as process by the makeFS function.
"LG-pts"Summary information of the pesudo-testcross linkage groups produced by the $createLG function.
"LG-comb"Summary information of the combined linkage groups produced by the $addBIsnps function.
"map"Summary information of the linkage maps produced by the $computeMap function.
IC object:
"data"Summary information of the data as process by the makeFS function.
"LG"Summary information of the pesudo-testcross linkage groups produced by the $createLG function.
"map"Summary information of the linkage maps produced by the $computeMap function.
Timothy P. Bilton
BC, FS, IC
## simulate some sequencing data
set.seed(6745)
config <- list(replicate(2,sample(c(1,2,4), size=30, replace=TRUE), simplify=FALSE))
F1data <- simFS(0.01, config=config, meanDepth=10, nInd=50)
# print summary information of data
F1data$print(what = "data")
## Compute 2-point recombination fractions
F1data$rf_2pt()
## create paternal and maternal linkage groups
F1data$createLG()
## Add BI SNPs
F1data$addBIsnps()
# print information of the combined linkage groups
F1data$print(what = "LG-comb")
#print both the data infromation and separate linkage groups
F1data$print(what = c("data", "LG-pts"))
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.