| mfun | R Documentation |
Transform recobination fractions into map distances using a specified mapping function.
mfun(rf, fun = "morgan", centiM = FALSE)
rf |
Vector of recombination fraction values |
fun |
Character vector giving the name of the mapping function (see details). |
centiM |
Logical value. If |
Currrently, the mapping implemented are:
fun="morgan")d = r
fun="haldane")d = -(1/2)ln(1 - 2r)
fun="kosambi")d = (1/4)ln((1+2r)/(1-2r))
where r denotes the recombination fraction value and d denotes the mapping distance value.
Timothy P. Bilton
$orderLG, $plotLM
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.